function LSUtilities(ScreenService, LSDataSourceUtilities, MessageService, localStorageEngine, ZHPromise, LibUtilities) {
    var self = this;

    this.dataSource = LSDataSourceUtilities;
    
    this.setLocalVar = function(key, value){
        localStorageEngine.setLocalVar(key, value);
    };
    
    this.getLocalVar = function(key){
        return localStorageEngine.getLocalVar(key);
    };

    this.defaultError = function(response) {
        return MessageService.getMessageByCode('login#ERR_UNEXPECTED_ERROR').then(function(defaultMessage) {
            if (response && response.data && response.data.error) {
                var error = response.data.error;
                if (self.isJson(error)) {
                    error = JSON.parse(error);
                    var params = error.PARAMS || null;
                    var messageCode = error.CODE || 'ERR_UNEXPECTED_ERROR';
                    if(messageCode == 'INVALID_PASSWORD_MASK') {
                        return showInvalidPasswordMaskMessage(messageCode, params);
                    } else {
                        return MessageService.getMessageByCode('login#' + messageCode).then(function (message) {
                            return ScreenService.showMessage(message, 'ERROR', null, params);
                        }).catch(function () {
                            return ScreenService.showMessage(messageCode, 'ERROR', null, params);
                        });
                    }
                } else {
                    var message = Util.isEmptyOrBlank(error) ? defaultMessage : error.split("Exception:").pop();
                    return ScreenService.showMessage(message, 'ERROR');
                }
            } else {
                return ScreenService.showMessage(defaultMessage, 'ERROR');
            }
        });
    };

    this.isJson = function(str) {
        var result = null;

        try {
            result = JSON.parse(str);
        } catch (e) { }

        return result;
    };

    var showInvalidPasswordMaskMessage = function(messageCode, params) {
        var promises = [];
        var messages = '';
        params.forEach(function(param) {
            if(param && param.EXISTS_MASK && param.INVALID_MASK) {
                var messagePromise = MessageService.getMessageByCode('login#' + param.MESSAGE).then(function(message) {
                    messages += '<li align="left">' + ScreenService.i18n(message, param.PARAMS) + '</li>';
                });
                promises.push(messagePromise);
            }
        });
        ZHPromise.all(promises).then(function() {
            MessageService.showMessageByCode('login#' + messageCode, { validations: messages }, { type: 'ALERT' });
        });
    };

    this.getNextUrl = function(route) {
        var token     = localStorage.getItem('LOGIN_TOKEN');
        var hash      = localStorage.getItem('LOGIN_HASH') || '0';
        var user      = localStorage.getItem('LOGIN_USER');
        var languange = localStorage.getItem('LOGIN_LANGUAGE');
        var productId = window.projectId;

        clearTimeout(LibUtilities.expiredSessionMethod);
        
        return window.nextUrl + "/" + route + "?header=0&menu=0" + 
            "&token=" + token + 
            "&hash=" + hash + 
            "&user=" + user + 
            "&languange=" + languange +
            "&productId=" + productId +
            "&isZhAngular=1";
    };


}

Configuration(function(ContextRegister) {
    ContextRegister.register('LSUtilities', LSUtilities);
});
